<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Play</source>
        <translation type="unfinished">&amp;Lejátszás</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>X</source>
        <translation type="unfinished">X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Pause</source>
        <translation type="unfinished">&amp;Szünet</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>C</source>
        <translation type="unfinished">C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Stop</source>
        <translation type="unfinished">&amp;Megállítás</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>V</source>
        <translation type="unfinished">V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Előző</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>Z</source>
        <translation type="unfinished">Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Következő</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>B</source>
        <translation type="unfinished">B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Play/Pause</source>
        <translation type="unfinished">&amp;Lejátszás/Szünet</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>Space</source>
        <translation type="unfinished">Szóköz</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>J</source>
        <translation type="unfinished">J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Jump to Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Playlist</source>
        <translation type="unfinished">Lista &amp;ismétlése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Repeat Track</source>
        <translation type="unfinished">Számok i&amp;smétlése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>Ctrl+R</source>
        <translation type="unfinished">Crtl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;Shuffle</source>
        <translation type="unfinished">&amp;Véletlenszerű</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>S</source>
        <translation type="unfinished">S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>&amp;No Playlist Advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>&amp;Stop After Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>&amp;Clear Queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>Alt+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Show Equalizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Alt+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Always on Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Put on All Workspaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Double Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add File</source>
        <translation type="unfinished">&amp;Fájl hozzáadása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>F</source>
        <translation type="unfinished">F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Directory</source>
        <translation type="unfinished">&amp;Könyvtár hazááadása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>D</source>
        <translation type="unfinished">D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Add Url</source>
        <translation type="unfinished">&amp;Url hozzáadása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>U</source>
        <translation type="unfinished">U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>&amp;Remove Selected</source>
        <translation type="unfinished">&amp;Megjelöltek eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>Del</source>
        <translation type="unfinished">Del</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove All</source>
        <translation type="unfinished">&amp;Összes eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="66"/>
        <source>&amp;Remove Unselected</source>
        <translation type="unfinished">&amp;Jelöletlenek eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="68"/>
        <source>Remove unavailable files</source>
        <translation type="unfinished">Elérhetetlen fájlok eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Remove duplicates</source>
        <translation type="unfinished">Duplikációk eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>&amp;Queue Toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Q</source>
        <translation type="unfinished">Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>Invert Selection</source>
        <translation type="unfinished">Fordított kijelölés</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select None</source>
        <translation type="unfinished">&amp;Kijelölés megszűntetése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>&amp;Select All</source>
        <translation type="unfinished">&amp;Összes kijelölése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Ctrl+A</source>
        <translation type="unfinished">Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>&amp;View Track Details</source>
        <translation type="unfinished">Szám adatainak &amp;megnézése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>Alt+I</source>
        <translation type="unfinished">Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;New List</source>
        <translation type="unfinished">&amp;Új lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Delete List</source>
        <translation type="unfinished">&amp;Lista törlése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>Ctrl+W</source>
        <translation type="unfinished">Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Load List</source>
        <translation type="unfinished">&amp;Lista betöltése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>O</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Save List</source>
        <translation type="unfinished">Lista &amp;mentése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>Shift+S</source>
        <translation type="unfinished">Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>&amp;Select Next Playlist</source>
        <translation type="unfinished">&amp;Következő lista választása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished">Ctrl+PgDown</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>&amp;Select Previous Playlist</source>
        <translation type="unfinished">&amp;Előző lista választása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished">Ctrl+PgUp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Show Playlists</source>
        <translation type="unfinished">&amp;Lejátszási lista mutatása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>P</source>
        <translation type="unfinished">P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Beállítások</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Névjegy</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;About Qt</source>
        <translation type="unfinished">N&amp;évjegy: Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>&amp;Exit</source>
        <translation type="unfinished">&amp;Kilépés</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="44"/>
        <source>Equalizer</source>
        <translation type="unfinished">Hangszínszabályzó</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="157"/>
        <location filename="../eqwidget.cpp" line="178"/>
        <source>preset</source>
        <translation>beállítás</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="264"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Betölt/Töröl</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="266"/>
        <source>&amp;Save Preset</source>
        <translation>Beálítás  &amp;mentése</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="268"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>&amp;Automatikusan betöltödő beállítás mentése</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Import</source>
        <translation>&amp;Importálás</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="273"/>
        <source>&amp;Clear</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="302"/>
        <source>Saving Preset</source>
        <translation>Beállítások mentése</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="303"/>
        <source>Preset name:</source>
        <translation>Beállítás neve:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="304"/>
        <source>preset #</source>
        <translation>beállítás #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="395"/>
        <source>Import Preset</source>
        <translation>Beállítás importálása</translation>
    </message>
</context>
<context>
    <name>HotkeyEditor</name>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="27"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="32"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="40"/>
        <source>Change shortcut...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="55"/>
        <source>Playback</source>
        <translation type="unfinished">Lejátszás</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="61"/>
        <source>View</source>
        <translation type="unfinished">Megnéz</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="67"/>
        <source>Playlist</source>
        <translation type="unfinished">Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="73"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Megállít</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Fájl hozzáadása</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Hangszínszabályzó</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Lista ismétlése</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Véletlenszerű</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Hangerő</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Egyensúly</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="243"/>
        <source>Visualization Mode</source>
        <translation>Vizualizációs mód</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="246"/>
        <source>Analyzer</source>
        <translation>Analyzer</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="247"/>
        <source>Scope</source>
        <translation>Scope</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="248"/>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="255"/>
        <source>Analyzer Mode</source>
        <translation>Analyzer mód</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="258"/>
        <source>Normal</source>
        <translation>Hagyományos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="259"/>
        <source>Fire</source>
        <translation>Tűz</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="260"/>
        <source>Vertical Lines</source>
        <translation>Függőleges vonalak</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="261"/>
        <source>Lines</source>
        <translation>Vonalak</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="262"/>
        <source>Bars</source>
        <translation>Csíkok</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="275"/>
        <source>Peaks</source>
        <translation>Csúcsok</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="279"/>
        <source>Refresh Rate</source>
        <translation>Ráta frissítése</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="282"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Falloff</source>
        <translation>Analízer esése</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <location filename="../mainvisual.cpp" line="309"/>
        <source>Slowest</source>
        <translation>Lassabb</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <location filename="../mainvisual.cpp" line="310"/>
        <source>Slow</source>
        <translation>Lassú</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <location filename="../mainvisual.cpp" line="311"/>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Fast</source>
        <translation>Gyors</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <location filename="../mainvisual.cpp" line="313"/>
        <source>Fastest</source>
        <translation>Gyorsabb</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="306"/>
        <source>Peaks Falloff</source>
        <translation>Csúcsok esése</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>Background</source>
        <translation>Háttér</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>Transparent</source>
        <translation>Átlátszóság</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Playlist</source>
        <translation type="unfinished">Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Appearance</source>
        <translation type="unfinished">Megjelenés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>View</source>
        <translation type="unfinished">Megnéz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation type="unfinished">Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <source>Sort List</source>
        <translation>Lista rendezése</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="210"/>
        <location filename="../playlist.cpp" line="253"/>
        <source>By Title</source>
        <translation>Cím szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="214"/>
        <location filename="../playlist.cpp" line="257"/>
        <source>By Album</source>
        <translation>Album szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="218"/>
        <location filename="../playlist.cpp" line="261"/>
        <source>By Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="222"/>
        <location filename="../playlist.cpp" line="265"/>
        <source>By Artist</source>
        <translation>Előadó szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="226"/>
        <location filename="../playlist.cpp" line="269"/>
        <source>By Filename</source>
        <translation>Fájlnév szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="230"/>
        <location filename="../playlist.cpp" line="273"/>
        <source>By Path + Filename</source>
        <translation>Elérési út és fájlnév szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="234"/>
        <location filename="../playlist.cpp" line="277"/>
        <source>By Date</source>
        <translation>Dátum szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="238"/>
        <location filename="../playlist.cpp" line="281"/>
        <source>By Track Number</source>
        <translation>Zene sorszáma szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="242"/>
        <location filename="../playlist.cpp" line="285"/>
        <source>By File Creation Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="250"/>
        <source>Sort Selection</source>
        <translation>Jelöltek rendezése</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="293"/>
        <source>Randomize List</source>
        <translation>Lista összekeverése</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="295"/>
        <source>Reverse List</source>
        <translation>Fordított lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="302"/>
        <source>Actions</source>
        <translation>Tevékenységek</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="565"/>
        <source>&amp;New PlayList</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="178"/>
        <source>&amp;Copy Selection To</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Lejátszási lista böngésző</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="40"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Rename</source>
        <translation>Átnevez</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="50"/>
        <source>&amp;Load</source>
        <translation>&amp;Betölt</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Mentés másként...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="53"/>
        <source>Rename</source>
        <translation>Átnevez</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Rename Playlist</source>
        <translation>Lista átnevezése</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Playlist name:</source>
        <translation>Lista neve:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Popup Információs Beállítások</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Borító mutatása</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Átlátszóság:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Borító mérete:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Sablon</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Visszaállít</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Beszúr</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Előadó</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Zeneszám</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Két jegyű zeneszám</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Műfaj</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Szerző</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Lemezszám</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Fájl neve</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Fájl útvonala</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Feltétel</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Beállítás szerkesztő</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Betölt</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Töröl</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Automatikus beállítás</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="52"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkinnedFactory</name>
    <message>
        <location filename="../skinnedfactory.cpp" line="31"/>
        <source>Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="44"/>
        <source>About Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="45"/>
        <source>Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="46"/>
        <source>Simple user interface with Winamp-2.x/XMMS skins support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="47"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="50"/>
        <source>Artwork:
Andrey Adreev &lt;andreev00@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkinnedSettings</name>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="24"/>
        <source>Skins</source>
        <translation type="unfinished">Skinek</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="55"/>
        <source>Add...</source>
        <translation type="unfinished">Hozzáad...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="68"/>
        <source>Refresh</source>
        <translation type="unfinished">Frissít</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="89"/>
        <location filename="../forms/skinnedsettings.ui" line="95"/>
        <source>View</source>
        <translation type="unfinished">Megnéz</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="101"/>
        <source>Hide on close</source>
        <translation type="unfinished">Elrejtés bezáráskor</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="108"/>
        <source>Start hidden</source>
        <translation type="unfinished">Rejtve induljon</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="115"/>
        <source>Use skin cursors</source>
        <translation type="unfinished">Skin egértéma használata</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="131"/>
        <source>Fonts</source>
        <translation type="unfinished">Betűtípus</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="149"/>
        <source>Player:</source>
        <translation type="unfinished">Lejátszó:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="171"/>
        <location filename="../forms/skinnedsettings.ui" line="219"/>
        <source>???</source>
        <translation type="unfinished">???</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="178"/>
        <location filename="../forms/skinnedsettings.ui" line="226"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="197"/>
        <source>Playlist:</source>
        <translation type="unfinished">Lejátszási lista:</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="233"/>
        <source>Use bitmap font if available</source>
        <translation type="unfinished">Bittérképes betűtípus használata, ha elérhető</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="243"/>
        <source>Transparency</source>
        <translation type="unfinished">Átlátszóság</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="249"/>
        <source>Main window</source>
        <translation type="unfinished">Fő ablak</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="272"/>
        <location filename="../forms/skinnedsettings.ui" line="296"/>
        <location filename="../forms/skinnedsettings.ui" line="320"/>
        <source>0</source>
        <translation type="unfinished">0</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="279"/>
        <source>Equalizer</source>
        <translation type="unfinished">Hangszínszabályzó</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="303"/>
        <source>Playlist</source>
        <translation type="unfinished">Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="344"/>
        <source>Miscellaneous</source>
        <translation type="unfinished">Vegyes</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="350"/>
        <source>Song Display</source>
        <translation type="unfinished">Szám kijelző</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="356"/>
        <source>Show protocol</source>
        <translation type="unfinished">Protokol mutatása</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="363"/>
        <source>Show song numbers</source>
        <translation type="unfinished">Zene sorszámának mutatása</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="387"/>
        <source>Show playlists</source>
        <translation type="unfinished">Lejátszási lista mutatása</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="394"/>
        <source>Show popup information</source>
        <translation type="unfinished">Felugró információk mutatása</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="406"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="430"/>
        <source>Playlist separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="468"/>
        <source>Show &apos;New Playlist&apos; button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="380"/>
        <source>Show anchor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="373"/>
        <source>Align song numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="101"/>
        <source>Select Skin Files</source>
        <translation type="unfinished">Skin fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="102"/>
        <source>Skin files</source>
        <translation type="unfinished">Skin fájlok</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="150"/>
        <source>Unarchived skin</source>
        <translation type="unfinished">Tömörítettlen skin</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="181"/>
        <source>Archived skin</source>
        <translation type="unfinished">Tömörített skin</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Számok címének görgetése</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="54"/>
        <source>Transparent Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="123"/>
        <source>Buffering: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="26"/>
        <source>Visualization</source>
        <translation>Vizualizáció</translation>
    </message>
</context>
</TS>
